@@ -51,12 +51,9 @@ class IsTextFile(object):
 		return self._call(filename)
 
 	def _is_text_magic(self, filename):
-		# regression in sys-apps/file causes
-		# py 3.2 & 3.3 magic module to not handle bytes properly
-		if isinstance(filename, bytes):
-			mime_type = self._m.file(str(filename))
-		else:
-			mime_type = self._m.file(filename)
+		mime_type = self._m.file(filename)
+		if isinstance(mime_type, bytes):
+			mime_type = mime_type.decode('ascii', 'replace')
 		return mime_type.startswith('text/')
 
 	def _is_text_encoding(self, filename):
