@@ -385,19 +385,9 @@ class InheritDeprecated(LineCheck):
 		"boost-utils": False,
 		"distutils": "distutils-r1",
 		"gems": "ruby-fakegem",
-		"git": "git-2",
 		"mono": "mono-env",
-		"mozconfig-2": "mozconfig-3",
-		"mozcoreconf": "mozcoreconf-2",
-		"php-ext-pecl-r1": "php-ext-pecl-r2",
-		"php-ext-source-r1": "php-ext-source-r2",
-		"php-pear": "php-pear-r1",
 		"python": "python-r1 / python-single-r1 / python-any-r1",
-		"python-distutils-ng": "python-r1 + distutils-r1",
-		"qt3": False,
-		"qt4": "qt4-r2",
 		"ruby": "ruby-ng",
-		"ruby-gnome2": "ruby-ng-gnome2",
 		"x-modular": "xorg-2",
 		}
 
